#!/bin/sh -efu

a= . install2-init-functions
. alterator-net-functions

CHKCONFIG=/sbin/chkconfig
SNORT_CONF="$destdir/etc/snort/snort.conf"
RULESDIR="$destdir/etc/snort/rules"
RESET_DB=/usr/lib/alterator-snort/reset-snort-db.sh
SYSCONFIG_FILE="$destdir/etc/sysconfig/snort"
ANE_HOOKSDIR="$destdir/usr/lib/alterator/hooks/net-eth.d"

# Remove commented rules files from snort.conf
sed -i '\;^#[[:blank:]]*include[[:blank:]]\$RULE_PATH/.\+\.rules$;d' "$SNORT_CONF"

# Remove empty rules files from snort.conf
for rule in $(sed -n 's;^[[:blank:]]*include[[:blank:]]\$RULE_PATH/\(.\+\)\.rules$;\1;p' "$SNORT_CONF"); do
    if ! grep -qs '^[^#]' "$RULESDIR/$rule.rules"; then
        sed -i "\;^[[:blank:]]*include[[:blank:]]\$RULE_PATH/$rule\.rules$;d" "$SNORT_CONF"
    fi
done

# Enable snort only for bridges if they exists
ifaces=
for i in $(list_iface); do
    ifaces="$ifaces${ifaces:+ }$i"
done
[ -n "$ifaces" ] && sed -i "s/^INTERFACES=any/INTERFACES=\"$ifaces\"/" "$SYSCONFIG_FILE"

# Create snort database, etc
exec_chroot "$RESET_DB" >/dev/null 2>&1

# Create hook for alterator-net-eth
mkdir -p "$ANE_HOOKSDIR"
cat > "$ANE_HOOKSDIR/50-snort" <<EOF
#!/bin/sh -eu

chkconfig snortd 2>/dev/null && \
! service snortd status >/dev/null 2>&1 && \
service snortd start >/dev/null 2>&1 ||:
EOF
chmod +x "$ANE_HOOKSDIR/50-snort"

# Enable services
exec_chroot $CHKCONFIG mysqld on ||:
exec_chroot $CHKCONFIG snortd on ||:
